/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext} from 'react';
import { Button } from '@material-ui/core';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Fade from '@material-ui/core/Fade';
import styled from 'styled-components'
import LoginContainer from './LoginContainer'
import {Store} from '../Store.js'
import axios from 'axios'
import {apiUrl} from '../env';

const StyledLogin = styled(Modal)`
    margin : 0 !important;
    margin-left : 0 !important;
    display : flex;
    align-items: center;
    justify-content : center;
    text-align : center;
    padding : 10px !important;
    border-radius : 4px;

`

export default function loginModal (props){
    const {state, dispatch} = useContext(Store)

    const handleLoginInfo = (login) => {
        axios.post(`${apiUrl}/auth/sign_in`,
            {
            email : login.email,
            password : login.senha
        }
        ).then( (response) => {
            dispatch ({
                type: "USER_LOGGED_IN",
                userLoggedIn: !state.userIsLoggedIn,
                login: {
                    username : login.username,
                    email : login.email,
                    accessToken : response.headers['access-token'],
                    client : response.headers.client
                    }
                }
            )
            props.handleClose();
            }, (error) => {
                console.log(':()')
            }
        )
    }


    return (
        <StyledLogin
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={props.open}
            animation={true}
            centered={true}
            onClose={props.handleClose}
            closeAfterTransition
            BackdropComponent={Backdrop}
            BackdropProps={{
                timeout: 500,
            }}
         >
            <Fade in={props.open}>
                <LoginContainer handleClose={props.handleClose}
                 openSignUp={props.openSignUp}
                 handleLoginInfo={handleLoginInfo}
                />
            </Fade>
        </StyledLogin>
    )
}
