/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, {useState, useContext}  from 'react';
import Card from '@material-ui/core/Card';
import CardActions from '@material-ui/core/CardActions';
import { Button } from '@material-ui/core';
import LabeledCheckbox from "../Components/Checkbox.js"
import styled from 'styled-components'
import {device} from '../Components/device.js'
import { Store } from '../Store.js';
import IllegalContentModal from '../Components/IllegalContentModal.js'
import PublicationPermissionsContent from '../Components/PublicationPermissionsContent.js'

const CardStyled = styled(Card)`
    box-sizing : border-box;
    background-color : white;
    max-width: 1700px;
    padding-top: 52px;
    margin-left:7em;
    @media ${device.mobileM} {
        width : 100%;
        height : 100%;
    }
 `

const Styledspan = styled.span`
    font-family: 'Roboto', sans serif;
    font-style: normal;
    font-weight: 500;
    line-height: 22px;
    font-size: 15px;
    letter-spacing: .01em;
`

const Styledhr = styled.hr`
    color: #dadada;
`

export default function permissionsContainer (props) {
    const {state, dispatch} = useContext(Store)
    const [unavailableCheckbox, setCheckboxAvailability] = useState(true);
    const [unavailableButton, setButtonAvailability] = useState(true);
    const [radios, setRadioValues] = useState({
        radio1 : '',
        radio2 : '' ,
        radio3 : ''
    }
    )
    const [modalOpen, setModalOpen] = useState(false)

    const closeModal = () => {
        setModalOpen(false)
        props.history.push('/termos-publicar-recurso')
        window.scrollTo(0, 0)
    }

    const handleChecked = e => {
        setButtonAvailability(!unavailableButton);
    }

    const handleRadios = (e) => {
        let temp = radios
        temp[e.target.name] = e.target.value

        setRadioValues(temp)


        setCheckboxAvailability(!(radios.radio1 && radios.radio2 && radios.radio3))

    }

    const handleAgreement = () => {

        if(radios.radio1 == 'Sim' || radios.radio2 == 'Sim' || radios.radio3 == 'Sim'){
                setModalOpen(true)
        }
        else{
            dispatch( {
                type: 'USER_AGREED_TO_PUBLICATION_PERMISSIONS',
                userAgreement: true
            })

            props.history.push('/upload')
        }
    }

    const redirect = () => {
        props.history.push('/termos-publicar-recurso')
    }

    return (
        <>
        {
            state.userAgreedToPublicationTerms ?
            (
                [
                <>
                <IllegalContentModal open={modalOpen} handleClose={closeModal} disableBackdropClick={true}/>
                <div style={{paddingTop:"5vh", paddingBottom:"5vh", backgroundColor :"#f4f4f4"}}>
                <div style={{}}>
                <CardStyled variant="outlined">
                    <PublicationPermissionsContent handleRadios={handleRadios} />
                    <Styledhr/>
                    <CardActions style={{justifyContent:"center", padding:"25px"}}>
                        <div>
                            <div style={{fontSize:"14px"}}>
                                <LabeledCheckbox disabledCheckbox = {unavailableCheckbox}
                                label={<Styledspan>Li e permito a publicação do meu recurso na Plataforma Integrada de RED do MEC, assim como atesto que o meu recurso atende aos critérios especificados acima.</Styledspan>}
                                handleChange={handleChecked}
                                />
                                    <div style={{justifyContent:"center",display:"flex"}}>
                                        <Button disabled={unavailableButton}
                                            style={unavailableButton ? {backgroundColor:"#e9e9e9"} : {backgroundColor:"#00bcd4"}}
                                            onClick={handleAgreement}
                                            >
                                                <Styledspan style = {unavailableButton ? {color:"#666666"} : {color:"#ffffff"}}>Continuar </Styledspan>
                                            </Button>
                                            <Button style={{marginLeft:"45px", backgroundColor:"#e9e9e9"}}>
                                                <Styledspan style={{color:"rgb(102, 102, 102)"}}>Cancelar</Styledspan>
                                            </Button>
                                        </div>
                                </div>
                        </div>
                    </CardActions>
                </CardStyled>
                </div>
                </div>
                </>
                ]
            )
            :
            (
                <>
                {redirect()}
                </>
            )
        }
        </>

    )
}
